@@ -72,8 +72,9 @@ public:
     {
     }
 
-    Akonadi::MessageQueueJob *
-    createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent = nullptr) override
+    Akonadi::MessageQueueJob *createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                                                    const KIdentityManagementCore::Identity &identity,
+                                                    QObject *parent = nullptr) override
     {
         Q_UNUSED(incidence)
         Q_UNUSED(identity)
@@ -657,7 +658,7 @@ void ITIPHandlerTest::onCreateFinished(int changeId, const Item &item, Incidence
 }
 
 void ITIPHandlerTest::onDeleteFinished(int changeId,
-                                       const QVector<Akonadi::Item::Id> &deletedIds,
+                                       const QList<Akonadi::Item::Id> &deletedIds,
                                        IncidenceChanger::ResultCode resultCode,
                                        const QString &errorString)
 {
@@ -688,3 +689,5 @@ void ITIPHandlerTest::onModifyFinished(int changeId, const Item &item, Incidence
 }
 
 QTEST_AKONADIMAIN(ITIPHandlerTest)
+
+#include "moc_itiphandlertest.cpp"
