@@ -103,7 +103,7 @@ public:
       @param email is a QString containing a email string in the
       "FirstName LastName <emailaddress>" format.
     */
-    Q_REQUIRED_RESULT KCalendarCore::FreeBusy::Ptr loadFreeBusy(const QString &email) override;
+    [[nodiscard]] KCalendarCore::FreeBusy::Ptr loadFreeBusy(const QString &email) override;
 
     /**
       Save freebusy information belonging to an email.
