@@ -12,30 +12,40 @@
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/ScheduleMessage>
-#include <KIdentityManagement/Identity>
-#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagementCore/Identity>
+#include <KIdentityManagementCore/IdentityManager>
 
 #include <KLocalizedString>
 #include <QStandardPaths>
 
 using namespace Akonadi;
-using namespace KIdentityManagement;
+using namespace KIdentityManagementCore;
 
 class Akonadi::MailSchedulerPrivate
 {
 public:
-    Q_REQUIRED_RESULT KIdentityManagement::Identity identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const;
-    Q_REQUIRED_RESULT KIdentityManagement::Identity identityForAddress(const QString &address) const;
+    [[nodiscard]] KIdentityManagementCore::Identity identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const;
+    [[nodiscard]] KIdentityManagementCore::Identity identityForAddress(const QString &address) const;
 
-    KIdentityManagement::IdentityManager *m_identityManager = nullptr;
+    MailClient::MailPrivacyFlags privacyFlags() const
+    {
+        MailClient::MailPrivacyFlags flags;
+        flags.setFlag(MailClient::MailPrivacySign, m_sign);
+        flags.setFlag(MailClient::MailPrivacyEncrypt, m_encrypt);
+        return flags;
+    }
+
+    KIdentityManagementCore::IdentityManager *m_identityManager = nullptr;
     MailClient *m_mailer = nullptr;
+    bool m_encrypt = false;
+    bool m_sign = false;
 };
 
 MailScheduler::MailScheduler(ITIPHandlerComponentFactory *factory, QObject *parent)
     : Scheduler(parent)
     , d(new MailSchedulerPrivate())
 {
-    d->m_identityManager = KIdentityManagement::IdentityManager::self();
+    d->m_identityManager = KIdentityManagementCore::IdentityManager::self();
     d->m_mailer = new MailClient(factory, parent);
 
     connect(d->m_mailer, &MailClient::finished, this, &MailScheduler::onMailerFinished);
@@ -46,14 +56,14 @@ MailScheduler::~MailScheduler()
     delete d->m_mailer;
 }
 
-KIdentityManagement::Identity MailSchedulerPrivate::identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const
+KIdentityManagementCore::Identity MailSchedulerPrivate::identityForIncidence(const KCalendarCore::IncidenceBase::Ptr &incidence) const
 {
     const auto organizer = incidence->organizer();
     const QString organizerEmail = !organizer.isEmpty() ? organizer.email() : CalendarUtils::email();
     return m_identityManager->identityForAddress(organizerEmail);
 }
 
-KIdentityManagement::Identity MailSchedulerPrivate::identityForAddress(const QString &address) const
+KIdentityManagementCore::Identity MailSchedulerPrivate::identityForAddress(const QString &address) const
 {
     return m_identityManager->identityForAddress(address);
 }
@@ -66,7 +76,15 @@ void MailScheduler::publish(const KCalendarCore::IncidenceBase::Ptr &incidence,
     }
 
     const QString messageText = mFormat->createScheduleMessage(incidence, KCalendarCore::iTIPPublish);
-    d->m_mailer->mailTo(incidence, d->identityForIncidence(incidence), CalendarUtils::email(), CalendarSettings::self()->bcc(), recipients, messageText);
+    d->m_mailer->mailTo(incidence,
+                        d->identityForIncidence(incidence),
+                        CalendarUtils::email(),
+                        KCalendarCore::iTIPPublish,
+                        CalendarSettings::self()->bcc(),
+                        recipients,
+                        messageText,
+                        {},
+                        d->privacyFlags());
 }
 
 void MailScheduler::performTransaction(const KCalendarCore::IncidenceBase::Ptr &incidence,
@@ -82,7 +100,7 @@ void MailScheduler::performTransaction(const KCalendarCore::IncidenceBase::Ptr &
 
     const auto identity = sender.isEmpty() ? d->identityForIncidence(incidence) : d->identityForAddress(sender);
 
-    d->m_mailer->mailTo(incidence, identity, Akonadi::CalendarUtils::email(), CalendarSettings::self()->bcc(), recipients, messageText);
+    d->m_mailer->mailTo(incidence, identity, Akonadi::CalendarUtils::email(), method, CalendarSettings::self()->bcc(), recipients, messageText, {}, d->privacyFlags());
 }
 
 void MailScheduler::performTransaction(const KCalendarCore::IncidenceBase::Ptr &incidence, KCalendarCore::iTIPMethod method, const QString &sender)
@@ -97,7 +115,7 @@ void MailScheduler::performTransaction(const KCalendarCore::IncidenceBase::Ptr &
 
     if (method == KCalendarCore::iTIPRequest || method == KCalendarCore::iTIPCancel || method == KCalendarCore::iTIPAdd
         || method == KCalendarCore::iTIPDeclineCounter) {
-        d->m_mailer->mailAttendees(incidence, identity, CalendarSettings::self()->bcc(), messageText);
+        d->m_mailer->mailAttendees(incidence, identity, method, CalendarSettings::self()->bcc(), messageText, {}, d->privacyFlags());
     } else {
         QString subject;
         KCalendarCore::Incidence::Ptr inc = incidence.dynamicCast<KCalendarCore::Incidence>();
@@ -107,7 +125,7 @@ void MailScheduler::performTransaction(const KCalendarCore::IncidenceBase::Ptr &
 
         const auto from = sender.isEmpty() ? CalendarUtils::email() : sender;
 
-        d->m_mailer->mailOrganizer(incidence, identity, sender, CalendarSettings::self()->bcc(), messageText, subject);
+        d->m_mailer->mailOrganizer(incidence, identity, sender, method, CalendarSettings::self()->bcc(), messageText, subject, {}, d->privacyFlags());
     }
 }
 
@@ -181,3 +199,15 @@ void MailScheduler::onMailerFinished(Akonadi::MailClient::Result result, const Q
         Q_EMIT transactionFinished(ResultGenericError, message);
     }
 }
+
+void MailScheduler::setEncrypt(bool encrypt)
+{
+    d->m_encrypt = encrypt;
+}
+
+void MailScheduler::setSign(bool sign)
+{
+    d->m_sign = sign;
+}
+
+#include "moc_mailscheduler_p.cpp"
